RequestConfiguration class

Contains targeting information that can be applied to all ad requests.

See relevant documentation at https://developers.google.com/ad-manager/mobile-ads-sdk/android/targeting#requestconfiguration.

Constructors

RequestConfiguration({String? maxAdContentRating, int? tagForChildDirectedTreatment, int? tagForUnderAgeOfConsent, List<String>? testDeviceIds})
Creates a RequestConfiguration.

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxAdContentRating → String?
Maximum content rating that will be shown.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagForChildDirectedTreatment → int?
Whether to tag as child directed.
final
tagForUnderAgeOfConsent → int?
Whether to tag as under age of consent.
final
testDeviceIds → List<String>?
List of test device ids to set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited