ConnectivityController mixin

A mixin for managing connectivity state

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConnected ↔ ValueNotifier<bool>
Notifier for tracking connectivity status
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initConnectivity({VoidCallback? onOnline, VoidCallback? onOffline}) → Future<void>
Initializes connectivity and sets up listeners for changes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited